@@ -24,4 +24,4 @@
 (sb-ext:save-lisp-and-die "createnode"
  :executable t
  :toplevel #'Scat.create-node::toplevel
- :purify t)
+ :purify NIL)
