@@ -23,4 +23,4 @@
 (sb-ext:save-lisp-and-die "listrange"
  :executable t
  :toplevel #'Scat.listrange::toplevel
- :purify t)
+ :purify NIL)
