@@ -134,11 +134,44 @@
       (symlink-in-dir SCAT.CFG::*PXE-CONFIG-DIR* state node-file))))
 
 (defun set-type (name type)
-  "set the type of a node"
+  " set the type of a node"
   (multiple-value-bind (node-type-file node-type)
       (type-existsp type)
     (let ((node-file (merge-pathnames Scat.Cfg::*node-image-dir* name)))
-      (symlink-in-dir Scat.Cfg::*node-image-dir* type name))))
+      (handler-bind ((SB-POSIX:SYSCALL-ERROR
+                      #'(lambda (c)
+                          (invoke-restart 'xxx))))
+        (restart-case (symlink-in-dir Scat.Cfg::*node-image-dir* type name)
+          (xxx () (progn (format t "name: ~A~%" name)
+                         (format t "~A~%" (merge-pathnames Scat.Cfg::*node-image-dir* name))
+                         (sb-posix:unlink (merge-pathnames Scat.Cfg::*node-image-dir* name))
+                         (symlink-in-dir Scat.Cfg::*node-image-dir* type name))))))))
+
+(defun list-type (name)
+  "list the type of a node"
+  (let* ((len (length (namestring Scat.Cfg::*node-image-dir*)))
+         (true (namestring (truename (merge-pathnames Scat.Cfg::*node-image-dir* name))))
+         (truelen (length true)))
+    (subseq true len (- truelen 1))))
+
+(defun list-mac (name)
+  "list the mac address for a node"
+  (let ((possible (scat.lib::list-symlinks-in-dir SCAT.CFG::*PXE-CONFIG-DIR*)))
+    (format () "~{~A~^:~}" 
+            (cdr 
+             (cl-ppcre::split 
+              "-" 
+              (cadr
+               (assoc name 
+                      (loop as file in possible
+                            collect 
+                            (list (sb-unix:unix-readlink 
+                                   (namestring 
+                                    (merge-pathnames 
+                                     file SCAT.CFG::*PXE-CONFIG-DIR*))) 
+                                  file))
+                      :test #'equal
+                      )))))))
 
 (defun name-mac (mac node)
   "link a node name to a mac address"
@@ -172,7 +205,11 @@
 (defun list-symlinks-in-dir (directory)
   (let ((files (list-files-in-dir directory)))
     (loop as file in files
-          when (not (equal (merge-pathnames file directory) (truename (merge-pathnames file directory))))
+          for name =  (if (COM.GIGAMONKEYS.PATHNAMES:DIRECTORY-P file)
+                          (merge-pathnames (format () "~A/" file) directory)
+                          (merge-pathnames file directory))
+          for true = (truename (merge-pathnames file directory))
+          when (not (equal name true))
           collect file)))
 
 (defun list-node-files ()
@@ -258,6 +295,7 @@
         (format NIL "$$~A$$" thing))))
 
 (defun replace-file (orig new)
+  (format t "replacing: ~A with: ~A~%" orig new)
   (with-open-file (orig-file orig)
     (with-open-file (new-file new :direction :output :if-exists :supersede)
       (loop for line = (read-line orig-file () ())
@@ -300,7 +338,14 @@
         (mapcar
          (lambda (file)
            (let ((basename (file-namestring file)))
-             (replace-file
-              file
-              (format () "~A~A" (directory-namestring new) basename))))
+             (if (cl-ppcre::scan "\\$\\$.*\\$\\$" basename)
+                 (replace-file
+                  file
+                  (format () "~A~A" (directory-namestring new)
+                          (cl-ppcre::regex-replace-all
+                           "\\$\\$(.*?)\\$\\$" basename 
+                           #'replace-text-macros)))
+                 (replace-file
+                  file
+                  (format () "~A~A" (directory-namestring new) basename)))))
          files)))))
